<?php

namespace Drupal\legalweb_cloud\Plugin\Block;

use Drupal\Core\Block\BlockBase;
use Drupal\Core\Plugin\ContainerFactoryPluginInterface;
use Drupal\Core\Render\Markup;
use Drupal\Core\StringTranslation\TranslatableMarkup;
use Symfony\Component\DependencyInjection\ContainerInterface;

/**
 * Provides a 'ImprintBlock' block.
 *
 * @Block(
 *  id = "legalweb_cloud_imprint_block",
 *  admin_label = @Translation("Imprint"),
 * )
 */
class ImprintBlock extends BlockBase implements ContainerFactoryPluginInterface {

  protected $manager;
  protected $lang_manager;

  /**
   * {@inheritdoc}
   */
  public static function create(ContainerInterface $container, array $configuration, $plugin_id, $plugin_definition) {
    $instance = new static($configuration, $plugin_id, $plugin_definition);
    $instance->manager = $container->get('legalweb_cloud.manager');
    $instance->lang_manager = $container->get('language_manager');
    return $instance;
  }

  /**
   * {@inheritdoc}
   */
  public function build() {
    $langcode = $this->lang_manager->getCurrentLanguage()->getId();
    $imprint = Markup::create($this->manager->getImprintHTML($langcode)) ??
      t('Imprint has not been configured properly at legalweb.io, please check the Documentation of this module.');

    // TODO: set cache tags/context here?
    $build = [
      '#theme' => 'legalweb_cloud_imprint',
      '#content' => $imprint,
    ];

    return $build;
  }

}
